@@ -178,6 +178,40 @@ If you want to backup your pogs, that's where ya go.
 
 %(copy)s""") % { "c":"fontypython", "folder":_pc.appPath(), "contact":contact, "copy":copyright }
 
+## These two are used in setup.py
+description = _("Fonty Python - manage fonts on Gnu/Linux")
+long_description = _("""Manage your fonts on Gnu/Linux.
+NEWS : We now support TTF, OTF, Type1 (PFB, PFM) 
+and TTC fonts.
+
+Many designers have collections of font files in big
+directory structures or on other media. Fonty Python
+will let you gather your fonts and structure them
+into collections -- or what I call "Pogs" -- a place
+to keep tyPOGraphy. Well, why not?
+
+Your fonts never move from where they are
+(so don't worry). All that happens is that you select 
+fonts visually and place their names into a Pog,
+then you install or uninstall Pogs as you need them.
+No copies of your fonts are made, only links to the
+original files are used to install the fonts.
+
+For example, you might have a Pog called "logos"
+into which you place all the ttfs you have of
+company logos. After that, when you need to work
+with those logos, you simply install the 'logos' Pog
+and start your design app!
+
+FP is also great for just looking at fonts wherever
+they are on your computer, without having to install
+them system-wide.
+    
+    %(copy)s
+    %(contact)s
+    """) % {"copy":copyright, "contact":contact}
+
+
 wxVersionError = _("""I cannot find "python-wxversion"
 Please install this package - NB: ensure that
 you use only the "Unicode build".
@@ -185,7 +219,7 @@ you use only the "Unicode build".
 TIP
 ===
 On my distro I can search for it like this:
-sudo aptitude search python-wx
+aptitude search python-wx
 This returns many results, one of which is:
 python-wxversion 
 I then install it like this:
@@ -206,7 +240,7 @@ you use only the "Unicode build".
 TIP
 ===
 On my distro I can search for it like this:
-sudo aptitude search python-wx
+aptitude search python-wx
 This returns many results, one of which is:
 python-wxgtk2.8
 I then install it like this:
@@ -224,7 +258,7 @@ Please install this package.
 TIP
 ===
 On my distro I can search for it like this:
-sudo aptitude search python-imag
+aptitude search python-imag
 This returns many results, one of which is:
 python-imaging
 I then install it like this:
